CHANGE LOG
==========

3.2.2
-----
- update UI fields on homepage
- Fix redirect issue when logging in

3.2.1
-----
- fix password reset
- add domain URLs for docker controllers
- tweaks to the UI

3.2.0
-----
- Added single-sign-on support for Molo
- Enable email login + password reset

3.1.1
-----
- Fix for marathon cmd when blank

3.1.0
-----
- Docker container now fully functional
- Use Environment variables to specify settings
- Add volume support use xylem plugin
- Allow marathon cmd to be blank for docker controller

3.0.5
-----
- ensure all static files are packaged

3.0.4
-----
- use json serialiser for celery

3.0.3
-----
- fix E402 in latest flake8 version

3.0.2
-----
- update celery to be inline with 3.1.19

3.0.1
-----
- make settings variables configurable via ENV

3.0.0
-----
- release as pip installable
- refactored namespace to use mc2
- allow deleting of app

2.0.0
-----
- Initial 2.0 release (non-backwards compatible)
- refactored code structure
- introduced controller base
- simplified model definitions

< 2.0
-----
- Mission Control for Universal Core
